#
# spec file for package python-azuremetadata
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1600
%define pythons %{primary_python}
%else
%{?sle15_python_module_pythons}
%endif
%global _sitelibdir %{%{pythons}_sitelib}

%define upstream_name azuremetadata
Name:           python-azuremetadata
Version:        5.1.6
Release:        1.1
Summary:        Python module for collecting instance metadata from Azure
License:        GPL-3.0-or-later
Group:          System/Management
URL:            https://github.com/SUSE-Enceladus/azuremetadata
Source0:        %{upstream_name}-%{version}.tar.bz2
BuildRequires:  %{pythons}-pip
BuildRequires:  %{pythons}-setuptools
BuildRequires:  %{pythons}-wheel
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Recommends:     util-linux
Conflicts:      regionServiceClientConfigAzure <= 0.0.4
Conflicts:      regionServiceClientConfigSAPAzure <= 1.0.1
# Package renamed in SLE15
Obsoletes:      azuremetadata < 5.0.0
Obsoletes:      python3-azuremetadata < %{version}
Obsoletes:      python310-azuremetadata < %{version}
Obsoletes:      python311-azuremetadata < %{version}
Obsoletes:      python312-azuremetadata < %{version}
Obsoletes:      python313-azuremetadata < %{version}
BuildArch:      noarch

%description
A module for collecting instance metadata from Microsoft Azure.

%prep
%autosetup -p1 -n %{upstream_name}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
install -d -m 755 %{buildroot}/%{_mandir}/man1
install -m 644 man/man1/azuremetadata.1 %{buildroot}/%{_mandir}/man1
%fdupes %{buildroot}%{_sitelibdir}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{upstream_name}
%{_sitelibdir}/%{upstream_name}
%{_sitelibdir}/%{upstream_name}-%{version}*-info
%{_mandir}/man1/%{upstream_name}.1%{?ext_man}

%changelog
* Thu Apr 17 2025 Robert Schweikert <rjschwei@suse.com>
- Update build setup
  + Switch source tarball name to be consistent with other tools of
    similar nature
  + Set the modules directory properly
* Fri Apr  4 2025 Robert Schweikert <rjschwei@suse.com>
- Version 5.1.6
  + Handle queries of attributes that return an empty list properly
  + Switch the package build to a specific Python interpreter set
    by the project configuration in the Build Service
* Thu May 30 2024 Matej Cepl <mcepl@cepl.eu>
- Replace python3-azuremetadata with universal packaging
  (https://trello.com/c/fupyiTVo/168-python3-packages-in-factory).
- Rename to python-azuremetadata.
* Thu Jan 13 2022 Robert Schweikert <rjschwei@suse.com>
- Version 5.1.5 (bsc#1194663)
  + Handle lsblk output format change. The json data now contains
    "mountpoints" instead of "mountpoint"
* Wed Apr 21 2021 Jesús Bermúdez Velázquez <jesusbv@suse.com>
- Version 5.1.4 (bsc#1184720, bsc#1172581)
  + Use versions endpoint to list the available versions
  + Add bypass proxy
  + Update way to check classic vms
* Fri Aug 21 2020 Robert Schweikert <rjschwei@suse.com>
- Fix provides directive (bsc#1175609, bsc#1175610)
  + The provides directive must set a version or update does not work
    as expected
* Fri Aug 21 2020 Robert Schweikert <rjschwei@suse.com>
- Fix provides directive (bsc#1175609, bsc#1175610)
  + The provides directive must set a version or update does not work
    as expected
* Mon Aug  3 2020 Robert Schweikert <rjschwei@suse.com>
- Update to version 5.1.2 (bsc#1173357, bsc#1174847)
  + Detect when the VM is running in ASM (Azure Classic) and handle the
    condition to generate the data we are interested in without requiring
    access to the full IMDS available only in ARM instances.
- From version 5.1.1 (bsc#1173238, bsc#1173240)
  + Add --listapis and --api latest support
* Mon Apr 27 2020 Ivan Kapelyukhin <ikapelyukhin@suse.com>
- Version 5.1.0
- Produce well-formed JSON and XML output when multiple filters
  are specified (bsc#1170598, bsc#1170599)
* Tue Apr 21 2020 Ivan Kapelyukhin <ikapelyukhin@suse.com>
- Version 5.0.1
- Use lsblk for root device detection (bsc#1169921)
* Tue Mar 31 2020 Ivan Kapelyukhin <ikapelyukhin@suse.com>
- Version 5.0.0
- Support new Azure metadata API (bsc#1164818, bsc#1164819)
- Automatically detect root device (bsc#1158698, bsc#1158707)
